scinumtools.units package
=========================

Submodules
----------

scinumtools.units.BaseUnitsClass module
---------------------------------------

.. automodule:: scinumtools.units.BaseUnitsClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.ConstantClass module
--------------------------------------

.. automodule:: scinumtools.units.ConstantClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.DimensionsClass module
----------------------------------------

.. automodule:: scinumtools.units.DimensionsClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.FractionClass module
--------------------------------------

.. automodule:: scinumtools.units.FractionClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.NaNClass module
---------------------------------

.. automodule:: scinumtools.units.NaNClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.QuantityClass module
--------------------------------------

.. automodule:: scinumtools.units.QuantityClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.UnitClass module
----------------------------------

.. automodule:: scinumtools.units.UnitClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.UnitConverters module
---------------------------------------

.. automodule:: scinumtools.units.UnitConverters
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.units.UnitList module
---------------------------------

.. automodule:: scinumtools.units.UnitList
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scinumtools.units
   :members:
   :undoc-members:
   :show-inheritance:
